## $Id: applicant.py 10132 2013-05-01 06:53:18Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from zope.interface import implementedBy
from waeup.kofa.applicants.applicant import ApplicantFactory
from waeup.kofa.utils.helpers import attrs_to_fields
from kofacustom.nigeria.applicants.applicant import NigeriaApplicant
from waeup.kwarapoly.applicants.interfaces import(
    ICustomApplicant, ICustomUGApplicantEdit, ICustomPGApplicantEdit, IPUTMEApplicantEdit)

class CustomApplicant(NigeriaApplicant):

    grok.implements(ICustomApplicant, ICustomUGApplicantEdit,
        ICustomPGApplicantEdit, IPUTMEApplicantEdit)
    grok.provides(ICustomApplicant)

    @property
    def is_nd(self):
        if self.applicant_id.startswith('nd') \
            or self.applicant_id.startswith('prend'):
            return True
        return False


# Set all attributes of CustomApplicant required in ICustomApplicant as field
# properties. Doing this, we do not have to set initial attributes
# ourselves and as a bonus we get free validation when an attribute is
# set.
CustomApplicant = attrs_to_fields(CustomApplicant)

class CustomApplicantFactory(ApplicantFactory):
    """A factory for customized applicants.
    """

    def __call__(self, *args, **kw):
        return CustomApplicant()

    def getInterfaces(self):
        return implementedBy(CustomApplicant)
